@@ -1,7 +1,7 @@
 """Functions to safely evaluate strings and inspect notebook."""
 import ast
+from collections import abc
 from copy import deepcopy
-from functools import reduce
 from itertools import compress
 from pathlib import Path
 from typing import Any, Callable, Dict, Iterable, List, Tuple
@@ -99,6 +99,26 @@ class DatabooksParser(ast.NodeVisitor):
             return True
         return not any(isinstance(f, ast.comprehension) for f in value)
 
+    @staticmethod
+    def _allowed_attr(obj: Any, attr: str, is_dynamic: bool = False) -> None:
+        """
+        Check that attribute is a key of `databooks.data_models.base.DatabooksBase`.
+
+        If `obj` is an iterable and was computed dynamically (that is, not originally in
+         scope but computed from a comprehension), check attributes for all elements in
+         the iterable.
+        """
+        allowed_attrs = list(dict(obj).keys()) if isinstance(obj, DatabooksBase) else ()
+        if isinstance(obj, abc.Iterable) and is_dynamic:
+            for el in obj:
+                DatabooksParser._allowed_attr(obj=el, attr=attr)
+        else:
+            if attr not in allowed_attrs:
+                raise ValueError(
+                    "Expected attribute to be one of"
+                    f" `{allowed_attrs}`, got `{attr}` for {obj}."
+                )
+
     def _get_iter(self, node: ast.AST) -> Iterable:
         """Use `DatabooksParser.safe_eval_ast` to get the iterable object."""
         tree = ast.Expression(body=node)
@@ -131,13 +151,7 @@ class DatabooksParser(ast.NodeVisitor):
                 "Expected `ast.comprehension`'s target to be `ast.Name`, got"
                 f" `ast.{type(node.target).__name__}`."
             )
-        # If any elements in the comprehension are a `DatabooksBase` instance, then
-        #  pass down the attributes as valid
-        iterable = self._get_iter(node.iter)
-        databooks_el = [el for el in iterable if isinstance(el, DatabooksBase)]
-        if databooks_el:
-            d_attrs = reduce(lambda a, b: {**a, **b}, [dict(el) for el in databooks_el])
-        self.names[node.target.id] = DatabooksBase(**d_attrs) if databooks_el else ...
+        self.names[node.target.id] = self._get_iter(node.iter)
         self.generic_visit(node)
 
     def visit_Attribute(self, node: ast.Attribute) -> None:
@@ -148,13 +162,11 @@ class DatabooksParser(ast.NodeVisitor):
                 f" `ast.Subscript`, got `ast.{type(node.value).__name__}`."
             )
         if isinstance(node.value, ast.Name):
-            obj = self.names[node.value.id]
-            allowed_attrs = dict(obj).keys() if isinstance(obj, DatabooksBase) else ()
-            if node.attr not in allowed_attrs:
-                raise ValueError(
-                    "Expected attribute to be one of"
-                    f" `{allowed_attrs}`, got `{node.attr}`"
-                )
+            self._allowed_attr(
+                obj=self.names[node.value.id],
+                attr=node.attr,
+                is_dynamic=node.value.id in (self.names.keys() - self.scope.keys()),
+            )
         self.generic_visit(node)
 
     def visit_Name(self, node: ast.Name) -> None:
